..
    Copyright (C) 2022 Graz University of Technology.

    invenio-moodle is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version v0.2.2 (release 2023-07-25)

- setup: fix typo, prevent correct build


Version v0.2.1 (release 2023-07-25)

- setup: change to reusable workflows


Version v0.2.0 (release 2023-07-25)



